@@ -149,16 +149,16 @@ class OvtpClient:
                 error = f"File {filename} does not exists!"
         raise RuntimeError(error)
 
-    async def read_with_prefix(self, timeout=5, retry=0):
+    async def read_with_prefix(self, timeout=5, retries=0):
         prefix_timeout = 30
         if timeout > prefix_timeout:
             prefix_timeout = timeout
         try:
             prefix = (await asyncio.wait_for(self.reader.readline(), timeout=prefix_timeout)).rstrip()
         except asyncio.exceptions.TimeoutError:
-            if retry:
-                print(f"Timeout error, but {retry} retry left")
-                return await self.read_with_prefix(timeout=timeout, retry=retry-1)
+            if retries:
+                print(f"Timeout error, but {retries} retries left")
+                return await self.read_with_prefix(timeout=timeout, retries=retries-1)
             else:
                 raise
         pk_data = b''
@@ -352,31 +352,33 @@ class OvtpClient:
             # await self.writer.wait_closed()
             return rcv_data
 
-    def send_message_sync(self, message, timeout=2, retry=0):
+    def send_message_sync(self, message, timeout=2, retries=0):
         return self.loop.run_until_complete(
-            self.send_message(message, timeout, retry)
+            self.send_message(message, timeout, retries)
         )
 
-    async def send_message(self, message, timeout=2, retry=0):
+    async def send_message(self, message, timeout=2, retries=0):
         await self.check_connection()
         try:
-            rcv = await self.send_data(self.server_address, data=message.encode(), timeout=timeout, retry=retry)
+            rcv = await self.send_data(self.server_address, data=message.encode(), timeout=timeout, retries=retries)
         except ConnectionResetError:
-            print('connection error')
+            if not retries:
+                raise
+            print(f'Connection error, {retries} left')
             await self.reconnect()
-            return await self.send_message(message, timeout=timeout, retry=retry)
+            return await self.send_message(message, timeout=timeout, retries=retries-1)
         if rcv == 'Access denied':
             self.server_public_key = None
             self.authorized = False
-            return await self.send_message(message, timeout=timeout, retry=retry)
+            return await self.send_message(message, timeout=timeout, retries=retries)
         elif not rcv:
             if self.verbose or self.debug:
                 print(f'Reconnecting to {self.server_address}...')
             # await self.close_connection()
-            return await self.send_message(message, timeout=timeout, retry=retry)
+            return await self.send_message(message, timeout=timeout, retries=retries)
         return rcv
 
-    async def send_data(self, address, data=b'', data_type='message', timeout=2, retry=0):
+    async def send_data(self, address, data=b'', data_type='message', timeout=2, retries=0):
         if not self.connected:
             await self.connect()
         #self.reader, self.writer = await asyncio.open_connection(
@@ -432,7 +434,7 @@ class OvtpClient:
             except:
                 print('not aes')
         # rcv_data = await self.reader.read(4096)
-        rcv_data = (await self.read_with_prefix(timeout=timeout, retry=retry))[0]
+        rcv_data = (await self.read_with_prefix(timeout=timeout, retries=retries))[0]
         # print(f'Encoded: {rcv_data}, len: {len(base64.b64decode(rcv_data))}')
         if data_type not in ['public_key', 'auth_req'] and self.server_public_key:
             # print(f'Decrypted: {aes.decrypt(rcv_data)}')
@@ -440,7 +442,7 @@ class OvtpClient:
                 rcv_data = self.aes.decrypt(rcv_data)
                 if data_type == 'message' and rcv_data == b'Sign ok':
                     sign_data = rcv_data  # Xz why
-                    rcv_data = self.aes.decrypt((await self.read_with_prefix(timeout=timeout, retry=retry))[0])
+                    rcv_data = self.aes.decrypt((await self.read_with_prefix(timeout=timeout, retries=retries))[0])
                 elif rcv_data == b'Sign error':
                     rcv_data = json.dumps({'status': False, 'description': 'Sign error'}).encode()
                 rcv_data = oe_common.fix_block_encoding_errors(rcv_data)
